Official Paayes Bindings for Python
===================================

A Python library for Paayes's API.


Setup
-----

You can install this package by using the pip tool and installing:

    $ pip install paayes

Or:

    $ easy_install paayes


Setting up a Paayes Account
---------------------------

Sign up for Paayes at https://dashboard.paayes.com/register.

Using the Paayes API
--------------------

Documentation for the python bindings can be found alongside Paayes's other bindings here:

- https://docs.paayes.com/docs/
- https://docs.paayes.com/api/python

In the standard documentation (the first link), most of the reference pages will have examples in Paayes's official bindings (including Python). Just click on the Python tab to get the relevant documentation.

In the full API reference for python (the second link), the right half of the page will provide example requests and responses for various API calls.
